/*
 * feedbackd
 *
 * Copyright (c) 2012 - 2017 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#include <stdio.h>
#include <stdlib.h>
#include <stdbool.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <time.h>
#include <fcntl.h>
#include <signal.h>
#include <dirent.h>
#include <ctype.h>
#include <string.h>
#include <stdarg.h>
#include <errno.h>
#include <poll.h>
#include <mntent.h>
#include <system_info.h>

#include "log.h"
#include "common.h"


int get_cmdline_name(pid_t pid, char *cmdline, size_t cmdline_size)
{
	int fd, ret;
	char buf[PATH_MAX + 1];
	char *filename;

	snprintf(buf, sizeof(buf), "/proc/%d/cmdline", pid);
	fd = open(buf, O_RDONLY);
	if (fd < 0) {
		errno = ESRCH;
		return -1;
	}

	ret = read(fd, buf, PATH_MAX);
	close(fd);
	if (ret < 0)
		return -1;

	buf[PATH_MAX] = '\0';

	filename = strrchr(buf, '/');
	if (filename == NULL)
		filename = buf;
	else
		filename = filename + 1;

	if (cmdline_size < strlen(filename) + 1) {
		errno = EOVERFLOW;
		return -1;
	}

	strncpy(cmdline, filename, cmdline_size - 1);
	cmdline[cmdline_size - 1] = '\0';
	return 0;
}

#define MODEL_NAME      "http://tizen.org/system/model_name"
#define MODEL_EMULATOR  "Emulator"

bool is_emulator(void)
{
	int ret;
	char *model_name = NULL;
	static bool emul = false;
	static int set = 0;

	if (set)
		return emul;

	ret = system_info_get_platform_string(MODEL_NAME, &model_name);
	if (ret < 0) {
		_E("Cannot get model name(%d)", ret);
		return emul;
	}

	if (!strncmp(MODEL_EMULATOR, model_name, strlen(model_name) + 1))
		emul = true;

	set = 1;
	free(model_name);

	return emul;
}
