/*
 * feedbackd
 *
 * Copyright (c) 2012 - 2017 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef __FEEDBACKD_COMMON_H__
#define __FEEDBACKD_COMMON_H__

#include <stdio.h>
#include <stdlib.h>
#include <error.h>
#include <stdbool.h>
#include <unistd.h>

#define ARRAY_SIZE(name) (sizeof(name)/sizeof(name[0]))
#define BITS_PER_LONG		(sizeof(long) * 8)
#define OFFSET(x)		((x) & (BITS_PER_LONG - 1))
#define BIT(x)			(1UL << OFFSET(x))
#define LONG(x)			((x) / BITS_PER_LONG)
#define test_bit(bit, array)	((array[LONG(bit)] >> OFFSET(bit)) & 1)

#ifndef __CONSTRUCTOR__
#define __CONSTRUCTOR__ __attribute__ ((constructor))
#endif

#ifndef __DESTRUCTOR__
#define __DESTRUCTOR__ __attribute__ ((destructor))
#endif

#ifndef __WEAK__
#define __WEAK__ __attribute__ ((weak))
#endif

#define NANO_SECOND_MULTIPLIER  1000000 /* 1ms = 1,000,000 nsec */

#ifndef safe_free
#define safe_free(x) safe_free_memory((void**)&(x))
#endif

static inline void safe_free_memory(void** mem)
{
	if (mem && *mem) {
		free(*mem);
		*mem = NULL;
	}
}

int get_cmdline_name(pid_t pid, char *cmdline, size_t cmdline_size);
bool is_emulator(void);

#endif	/* __FEEDBACKD_COMMON_H__ */

